@@ -21,6 +21,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   } else { #multiple files
     filelist = TRUE
   }
+
   derivef0f1 = FALSE
   if (length(f0) == 0 | length(f1) == 0) {
     derivef0f1 = TRUE
@@ -32,10 +33,10 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     f0 = 1
     # What file to end with?
     if (filelist == FALSE) {
-      if (f1 != f0) {
-        fl <- length(dir(datadir, recursive = TRUE, pattern = "[.](csv|bin|Rda)")) # modified by JH
+      # if (f1 != f0) {
+        f1 <- length(dir(datadir, recursive = TRUE, pattern = "[.](csv|bin|Rda|wa)")) # modified by JH
         # f1 = length(c(dir(datadir,recursive=TRUE,pattern="csv"),dir(datadir,recursive=TRUE,pattern="bin"))) #10
-      }
+      # }
     } else {
       f1 = length(datadir) #modified
     }
@@ -46,14 +47,14 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     dopart2 = TRUE
     dopart3 = TRUE
     dopart4 = TRUE
-    # dopart5 = TRUE
+    dopart5 = TRUE
   } else {
     # if (length(which(mode == 0)) > 0) dopart0 = TRUE
     if (length(which(mode == 1)) > 0) dopart1 = TRUE
     if (length(which(mode == 2)) > 0) dopart2 = TRUE
     if (length(which(mode == 3)) > 0) dopart3 = TRUE; do.anglez = TRUE
     if (length(which(mode == 4)) > 0) dopart4 = TRUE
-    # if (length(which(mode == 5)) > 0) dopart5 = TRUE
+    if (length(which(mode == 5)) > 0) dopart5 = TRUE
   }
   
   # test whether RData input was used and if so, use original outputfolder
@@ -80,7 +81,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   } else {
     useRDA = FALSE
   }
-  
+
   if (filelist == TRUE | useRDA == TRUE) {
     metadatadir = paste(outputdir,"/output_",studyname,sep="")
   } else {
@@ -158,16 +159,16 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "closedbout")) == 0)  closedbout = FALSE
   
   # # specific for part 5
-#   if (length(which(ls() == "boutcriter.in")) == 0)  boutcriter.in = 0.9
-#   if (length(which(ls() == "boutcriter.lig")) == 0)  boutcriter.lig = 0.8
-#   if (length(which(ls() == "boutcriter.mvpa")) == 0)  boutcriter.mvpa = 0.8
-#   if (length(which(ls() == "threshold.lig")) == 0)  threshold.lig = 40
-#   if (length(which(ls() == "threshold.mod")) == 0)  threshold.mod = 100
-#   if (length(which(ls() == "threshold.vig")) == 0)  threshold.vig = 400
-#   if (length(which(ls() == "timewindow")) == 0)  timewindow = c("MM","WW")
-#   if (length(which(ls() == "boutdur.mvpa")) == 0)  boutdur.mvpa = c(1,5,10)
-#   if (length(which(ls() == "boutdur.in")) == 0)  boutdur.in = c(10,20,30)
-#   if (length(which(ls() == "boutdur.lig")) == 0)  boutdur.lig = c(1,5,10)
+  if (length(which(ls() == "boutcriter.in")) == 0)  boutcriter.in = 0.9
+  if (length(which(ls() == "boutcriter.lig")) == 0)  boutcriter.lig = 0.8
+  if (length(which(ls() == "boutcriter.mvpa")) == 0)  boutcriter.mvpa = 0.8
+  if (length(which(ls() == "threshold.lig")) == 0)  threshold.lig = 40
+  if (length(which(ls() == "threshold.mod")) == 0)  threshold.mod = 100
+  if (length(which(ls() == "threshold.vig")) == 0)  threshold.vig = 400
+  if (length(which(ls() == "timewindow")) == 0)  timewindow = c("MM","WW")
+  if (length(which(ls() == "boutdur.mvpa")) == 0)  boutdur.mvpa = c(1,5,10)
+  if (length(which(ls() == "boutdur.in")) == 0)  boutdur.in = c(10,20,30)
+  if (length(which(ls() == "boutdur.lig")) == 0)  boutdur.lig = c(1,5,10)
   
   # part 2
   if (length(which(ls() == "mvpadur")) == 0)  mvpadur = c(1,5,10) # related to part 2 (functionality to anticipate part 5)
@@ -177,7 +178,6 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "dayborder")) == 0)  dayborder = 0
   
   cat("\n   g.shell.GGIR {GGIR} by Vincent van Hees\n")
-  
   if (dopart1 == TRUE) {
     cat('\n')
     cat(paste0(rep('_',options()$width),collapse=''))
@@ -234,26 +234,26 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
             sleeplogidnum=sleeplogidnum,def.noc.sleep=def.noc.sleep,do.visual = do.visual, #
             storefolderstructure=storefolderstructure,overwrite=overwrite)
   }
-#   if (dopart5 == TRUE) {
-#     cat('\n')
-#     cat(paste0(rep('_',options()$width),collapse=''))
-#     cat("\nPart 5\n")
-#     if (f1 == 0) f1 = length(dir(paste(metadatadir,"/meta/ms4.out",sep="")))
-#     g.part5(datadir=datadir,metadatadir=metadatadir,f0=f0,f1=f1,strategy=strategy,maxdur=maxdur,
-#             hrs.del.start=hrs.del.start,
-#             hrs.del.end=hrs.del.end,
-#             loglocation=loglocation,excludefirstlast=excludefirstlast,
-#             windowsizes=windowsizes,boutcriter.in=boutcriter.in,boutcriter.lig=boutcriter.lig,
-#             boutcriter.mvpa=boutcriter.mvpa,storefolderstructure=storefolderstructure,
-#             threshold.lig = threshold.lig,
-#             threshold.mod = threshold.mod,
-#             threshold.vig = threshold.vig,timewindow=timewindow,
-#             boutdur.mvpa = boutdur.mvpa,
-#             boutdur.in = boutdur.in,
-#             boutdur.lig = boutdur.lig,
-#             winhr = winhr,M5L5res = M5L5res,
-#             overwrite=overwrite,desiredtz=desiredtz)
-#   }
+  if (dopart5 == TRUE) {
+    cat('\n')
+    cat(paste0(rep('_',options()$width),collapse=''))
+    cat("\nPart 5\n")
+    if (f1 == 0) f1 = length(dir(paste(metadatadir,"/meta/ms4.out",sep="")))
+    g.part5(datadir=datadir,metadatadir=metadatadir,f0=f0,f1=f1,strategy=strategy,maxdur=maxdur,
+            hrs.del.start=hrs.del.start,
+            hrs.del.end=hrs.del.end,
+            loglocation=loglocation,excludefirstlast=excludefirstlast,
+            windowsizes=windowsizes,boutcriter.in=boutcriter.in,boutcriter.lig=boutcriter.lig,
+            boutcriter.mvpa=boutcriter.mvpa,storefolderstructure=storefolderstructure,
+            threshold.lig = threshold.lig,
+            threshold.mod = threshold.mod,
+            threshold.vig = threshold.vig,timewindow=timewindow,
+            boutdur.mvpa = boutdur.mvpa,
+            boutdur.in = boutdur.in,
+            boutdur.lig = boutdur.lig,
+            winhr = winhr,M5L5res = M5L5res,
+            overwrite=overwrite,desiredtz=desiredtz)
+  }
   
   #==========================
   # Report generation:
@@ -292,17 +292,17 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     g.report.part4(datadir=datadir,metadatadir=metadatadir,loglocation =loglocation,f0=f0,f1=f1,
                    storefolderstructure=storefolderstructure)
   }
-#   if (length(which(do.report == 5)) > 0) {
-#     cat('\n')
-#     cat(paste0(rep('_',options()$width),collapse=''))
-#     cat("\nReport part 5\n")
-#     N.files.ms5.out = length(dir(paste(metadatadir,"/meta/ms5.out",sep="")))
-#     if (N.files.ms5.out < f0) f0 = 1
-#     if (N.files.ms5.out < f1) f1 = N.files.ms5.out
-#     if (f1 == 0) f1 = N.files.ms5.out
-#     g.part5.report(metadatadir=metadatadir,f0=f0,f1=f1,loglocation=loglocation,
-#                    includenightcrit=includenightcrit,includedaycrit=includedaycrit)
-#   }
+  if (length(which(do.report == 5)) > 0) {
+    cat('\n')
+    cat(paste0(rep('_',options()$width),collapse=''))
+    cat("\nReport part 5\n")
+    N.files.ms5.out = length(dir(paste(metadatadir,"/meta/ms5.out",sep="")))
+    if (N.files.ms5.out < f0) f0 = 1
+    if (N.files.ms5.out < f1) f1 = N.files.ms5.out
+    if (f1 == 0) f1 = N.files.ms5.out
+    g.part5.report(metadatadir=metadatadir,f0=f0,f1=f1,loglocation=loglocation,
+                   includenightcrit=includenightcrit,includedaycrit=includedaycrit)
+  }
   if (visualreport == TRUE) {
     cat('\n')
     cat(paste0(rep('_',options()$width),collapse=''))
