@@ -55,7 +55,7 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
         # count posture changes that happen less than once per ten minutes
         q1 = c()
         if (length(postch) > 1) {
-          q1 = which(diff(postch) > (i*12)) #less than once per i minutes
+          q1 = which(diff(postch) > (i*(60/ws3))) #less than once per i minutes
         }
         if (length(q1) > 0) {
           for (gi in 1:length(q1)) {
